branch: externals/guess-language
commit 889b9aad63fb0c88e6b6d3b312ccce520fcaa7ac
Author: Titus von der Malsburg <[email protected]>
Commit: Titus von der Malsburg <[email protected]>
Dansk -> Danish
---
README.org | 4 ++--
guess-language.el | 4 ++--
2 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/README.org b/README.org
index 5aafaff..b4e8669 100644
--- a/README.org
+++ b/README.org
@@ -9,7 +9,7 @@
I write a lot of text in multiple languages and was getting tired of
constantly having to switch the dictionary of my spell-checker. In true Emacs
spirit, I decided to dust off my grandpa's parentheses and wrote some code to
address this problem. The result is ~guess-language-mode~, a minor mode for
Emacs that guesses the language of the current paragraph and then changes the
dictionary of ispell and the language settings of typo-mode. It also reruns
Flyspell on the current paragraph, [...]
-Currently, the following languages are supported: Czech, Dansk, Dutch,
English, Finnish, French, German, Italian, Norwegian, Polish, Portuguese,
Russian, Slovak, Slovenian, Swedish. It is very easy to add more languages and
this repository includes the necessary language statistics for 49 additional
languages. (These were copied from
[[https://github.com/kent37/guess-language][guess_language.py]].)
+Currently, the following languages are supported: Czech, Danish, Dutch,
English, Finnish, French, German, Italian, Norwegian, Polish, Portuguese,
Russian, Slovak, Slovenian, Swedish. It is very easy to add more languages and
this repository includes the necessary language statistics for 49 additional
languages. (These were copied from
[[https://github.com/kent37/guess-language][guess_language.py]].)
** Prerequisites
@@ -30,7 +30,7 @@ Available languages at this time:
| IDO 639-1 code | Language |
|----------------+------------|
| ~cs~ | Czech |
-| ~da~ | Dansk |
+| ~da~ | Danish |
| ~nl~ | Dutch |
| ~en~ | English |
| ~fi~ | Finnish |
diff --git a/guess-language.el b/guess-language.el
index 6bef954..7e357b4 100644
--- a/guess-language.el
+++ b/guess-language.el
@@ -30,7 +30,7 @@
;; there is likely not enough text to guess the language correctly.
;;
;; The detection algorithm is based on counts of character
;; trigrams. At this time, supported languages are Czech, Dansk,
;; Dutch, English, Finnish, French, German, Italian, Norwegian,
;; Polish, Portuguese, Russian, Slovak, Slovenian, Swedish. Adding
;; further languages is very easy and this package already contains
@@ -52,7 +52,7 @@
Uses ISO 639-1 identifiers. Currently supported languages are:
cs: Czech
- da: Dansk
+ da: Danish
nl: Dutch
en: English
fi: Finnish
@@ -30,7 +30,7 @@
;;
;; The detection algorithm is based on counts of character
-;; trigrams. At this time, supported languages are Czech, Dansk,
+;; trigrams. At this time, supported languages are Czech, Danish,
;; Dutch, English, Finnish, French, German, Italian, Norwegian,
;; Polish, Portuguese, Russian, Slovak, Slovenian, Swedish. Adding